# with open("input.txt", "r") as f:
#     domain = f.read().strip()


def get_patterns(domain):
    web_ports = ['587', '443' '80', '8080']
    patterns = [
        # user;password;https://server
        r'^(?P<User>[^;\s]+)\s*;\s*(?P<Password>[^;\s]+)\s*;\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s;]+)"?$',
        rf"^(?P<User>[^;\s]+)\s*;\s*(?P<Password>[^;\s]+)\s*;\s*(?P<Server>[^\s;]+\.{domain}[^\s;]*)$",
        # user;password;https://server
        rf"^(?P<User>[^;:\s]+)\s*;\s*(?P<Password>[^:\s]+)\s*;(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^\s:]+\.{domain}[^\s;]*)$",
        # user;password:https://server
        r'^(?P<User>[^;:\s]+)\s*;\s*(?P<Password>[^:\s]+)\s*:\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?$',
        rf"^(?P<User>[^;:\s]+)\s*;\s*(?P<Password>[^:\s]+)\s*:\s*(?P<Server>[^\s:]+\.{domain}[^\s;]*)$",
        # user:password;https://server
        r'^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^;\s]+)\s*;\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s;]+)"?$',
        rf"^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^;\s]+)\s*;\s*(?P<Server>[^\s;]+\.{domain}[^\s;]*)$",
        # https://server|user|password
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s|;]+)"?\s*\|\s*(?P<User>[^|]*)\s*\|\s*(?P<Password>[^\s]*)$',
        rf"^(?P<Server>[^\s]+\.{domain}[^\s]*)\s*\|\s*(?P<User>[^|\s]*)\s*\|\s*(?P<Password>[^\s]*)$",
        # android://server|user|password
        r'^(?P<Server>android://[^\s|;]+)\s*\|\s*(?P<User>[^|]*)\s*\|\s*(?P<Password>[^\s]*)$',
        # user:password:https://server
        r'^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:\s]+)\s*:\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?$',
        rf"^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:\s]+)\s*:\s*(?P<Server>[^\s:]+\.{domain}[^\s:]*)$",
        rf"^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:\s]+)\s*:\s*(?P<Server>{domain}[^\s:]*)$",
        # user:password:server(domain static) fix2
        # https://server:user:sub-user:password
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^"\s:]+[:8080\/$]+)"?\s*:\s*(?P<User>[^\s]*)\s*:\s*(?P<Password>[^\s]*)$',
        # server, user, pass and port
        rf"^(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^:\s]+:{'|'.join(web_ports)})?\s*:\s*(?P<User>[^:]+)\s*:\s*(?P<Password>[^\s]*)$",
        # fix3
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*:\s*(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^\s]*)$',
        # https://server:user:password
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*:\s*(?P<User>[^:]*)\s*:\s*(?P<Password>[^:\s]*)$',
        # android://server:user:password
        r"^(?P<Server>android://[^\s:]+)\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^\s]+)$",
        # https://server user:sub-user:password
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s]+)"?\s+(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^\s]*)$',
        # android://server user:sub-user:password
        r"^(?P<Server>android://[^\s]+)\s+(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^\s]*)$",
        # https://server user:password
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^"\s]+)"?\s+(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$',
        # android://server user:password
        r"^(?P<Server>android://[^\s]+)\s+(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$",
        # domain Url: https://server user:password
        rf'^{domain} Url: "?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^"\s]+)"?\s+(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$',
        # user:password https://server
        r'^(?P<User>[^\s:]*)\s*:\s*(?P<Password>[^\s]*)\s+"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s]+)"?$',
        # https://server;user:password
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^"\s]+)"?\s*;\s*(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$',
        # https://server:user
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*:\s*(?P<User>[^:\s]+)$',
        # https://server
        r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*$',
        # user,password,https://server
        r'^(?P<User>[^,\s]+)\s*,\s*(?P<Password>[^,\s]+)\s*,\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s,]+)"?$',
        rf"^(?P<User>[^,\s]+)\s*,\s*(?P<Password>[^,\s]+)\s*,\s*(?P<Server>[^\s]+\.{domain}[^\s,]*)$",
        # example subdomain.domain.com/:(subdomain.domain.com/):login:pass - remove second domain Server2
        rf'^(?P<Server>[^@\s]*{domain}[^\s]*):\([^@\s]*{domain}[^\s]*\)\s*\s*(?P<Server2>[^:]*)\s*:\s*(?P<User>[^:]*)\s*:\s*(?P<Password>[^:\s]*)$',
        # fix4
        # server:user:sub-user:password
        rf'^(?P<Server>[^@\s]*{domain}[^\s]*)\s*:\s*(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^:\s]*)$',
        rf"^/?(?P<Server>[^@\s]*{domain}[^\s]*)\s*\:\s*(?P<User>[^|\s]*)\s*\:\s*(?P<Password>[^\s]*)$",
        # server:user:password
        rf'^(?P<Server>[^@\s]*{domain}[^\s]*)\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:\s]+)$',
        # server user:password
        rf"^(?P<Server>[^@\s]*{domain}[^\s]*)\s+(?P<User>[^\s:]+)\s*:\s*(?P<Password>[^\s]+)$",
        # spaced-user:password:https://server
        r"^(?P<User>[^:]+)\s*:\s*(?P<Password>[^:\s]+)\s*:\s*(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^\s:]+)$",
        # https://server:user:spaced-password
        r"^(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^\s:]+)\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:]+)$",
        # javascript:;:user:password
        r"^javascript:;\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^\s]+)$",
        # password:user:hash
        r"(?P<Password>[^\s:]+):(?P<User>[^@|\s,]+@[^:;\s]+):(?P<Hash>[a-f0-9]{32})",
        # username:password:user
        r"^(?P<UserName>[^/.,]+):(?P<Password>[^;:\s,]+):(?P<User>[^'\"|;\s,]+@[^|;\"\s',]+)",
        # fake-server:user:password and port
        rf"^(?P<Server>[\w\s@\=.\/&-]+:{'|'.join(web_ports)})\s*:\s*(?P<User>[^:][\w@.-]+)\s*:\s*(?P<Password>[^\s]+)$",
        # fake-server:user:password
        r"^(?P<Server>[\w\s@\=.\/&-]+)\s*:\s*(?P<User>[^:][\w@.-]+)\s*:\s*(?P<Password>[^\s]+)$",
        # user:password[without-space]
        r"^(?P<User>[^,:;|\s]+)\s*:\s*(?P<Password>[^:\s]+)$",
        # email: (user without password and server)
        r"^(?P<User>[^@|\s]+@[^:;|\s]+)\s*:\s*$",
        # useless-chars;user:password
        # r"(?<=;)(?P<User>[^;@|\s]+@[^:;|\s]+)\s*:\s*(?P<Password>[^\s]+)$",
        # :user:password
        r"^:\s*(?P<User>[^@|\s]+@[^:;|\s]+)\s*:\s*(?P<Password>[^\s]+)$",
        # date;password;user:hash
        r"^(?P<Date>[0-9-]+);(?P<Password>[^\s;]+);(?P<User>[^@|\s]+@[^:;\s]+):(?P<Hash>[a-f0-9]{32})$",
        # password,user,hash
        r"^(?P<Password>[^\s,]+),(?P<User>[^@|\s,]+@[^:;\s,]+),(?P<Hash>[a-f0-9]{32})$",
        # username,password,user
        r"^(?P<UserName>[^,]+),(?P<Password>[^;:\s,]+),(?P<User>[^'\"|;\s,]+@[^|;\"\s',]+)",
        # user password[digits]
        r"^(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+)\s+(?P<Password>\d+)$",
        # user,password[char-digits]
        r"^(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+),(?P<Password>[a-z0-9]+)$",
        # user;password[char-digits]
        r"^(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+);(?P<Password>[a-z0-9]+)$",
        # user:password[with-space]
        r"^(?P<User>[^,:;|\s]+)\s*:\s*(?P<Password>[\w\s@-]+)$",
        # email in SQL
        r"(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+)",
        # generic server name
        rf"^(?P<Server>[^@\s]+{domain}[^\s]*)$",
        # generic user name
        r"^(?P<User>[\w\s@.-]+)$",
    ]

    return patterns


def get_email_group_pattern():
    return '(?P<Email>[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.(({})|[a-zA-Z]{{2,3}}))'.format('|'.join(common_domain_names))


common_domain_names = [
    'com',
    'net',
    'org',
    'jp',
    'de',
    'uk',
    'fr',
    'br',
    'it',
    'ru',
    'es',
    'me',
    'gov',
    'pl',
    'ca',
    'au',
    'cn',
    'co',
    'in',
    'nl',
    'edu',
    'info',
    'eu',
    'ch',
    'id',
    'at',
    'kr',
    'cz',
    'mx',
    'be',
    'tv',
    'se',
    'tr',
    'tw',
    'al',
    'ua',
    'ir',
    'vn',
    'cl',
    'sk',
    'ly',
    'cc',
    'to',
    'no',
    'fi',
    'us',
    'pt',
    'dk',
    'ar',
    'hu',
    'tk',
    'gr',
    'il',
    'news',
    'ro',
    'my',
    'biz',
    'ie',
    'za',
    'nz',
    'sg',
    'ee',
    'th',
    'io',
    'xyz',
    'pe',
    'bg',
    'hk',
    'rs',
    'lt',
    'link',
    'ph',
    'club',
    'si',
    'site',
    'mobi',
    'by',
    'cat',
    'wiki',
    'la',
    'ga',
    'xxx',
    'cf',
    'hr',
    'ng',
    'jobs',
    'onlin',
    'kz',
    'ug',
    'gq',
    'ae',
    'is',
    'lv',
    'pro',
    'fm',
    'tips',
    'ms',
    'sa',
    'app'
] 